@@ -301,12 +301,9 @@ CALDAV_RESPONSE caldav_get_object(response *result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = GET;
 	settings.start = start;
@@ -365,12 +362,9 @@ CALDAV_RESPONSE caldav_getall_object(response* result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = GETALL;
 	if (info->options->debug)
@@ -547,12 +541,9 @@ CALDAV_RESPONSE caldav_tasks_get_object(response *result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = GETTASKS;
 	settings.start = start;
@@ -611,12 +602,9 @@ CALDAV_RESPONSE caldav_tasks_getall_object(response* result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = GETALLTASKS;
 	if (info->options->debug)
@@ -673,12 +661,9 @@ CALDAV_RESPONSE caldav_get_displayname(response* result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = GETCALNAME;
 	if (info->options->debug)
@@ -788,12 +773,9 @@ CALDAV_RESPONSE caldav_get_freebusy(response *result,
 	CALDAV_RESPONSE caldav_response;
 
 	g_return_val_if_fail(info != NULL, TRUE);
+	g_return_val_if_fail(result != NULL, NOTIMPLEMENTED);
 
 	init_runtime(info);
-	if (!result) {
-		result = malloc(sizeof(response *));
-		memset(result, '\0', sizeof(response *));
-	}
 	init_caldav_settings(&settings);
 	settings.ACTION = FREEBUSY;
 	settings.start = start;
